Common API
==========

This document describes ``DistMQTT`` common API both used by :doc:`mqttclient` and :doc:`broker`.

Reference
---------

ApplicationMessage
..................

.. automodule:: distmqtt.session

    .. autoclass:: ApplicationMessage
        :members:

    .. autoclass:: IncomingApplicationMessage
        :show-inheritance:

    .. autoclass:: OutgoingApplicationMessage
        :show-inheritance:
